@@ -11,6 +11,11 @@ class CaptainHook:
     def __init__(self, config):
         self._baseurl = config.user["captainhook_url"]
         self._timeout = config.user["captainhook_timeout"]
+        self._auth0_tenant = config.auth0["tenant"]
+        self._auth0_token = config.get_cache(f"{self._auth0_tenant}_auth0_token")
+        self._headers = {
+            "Authorization": f"Bearer {self._auth0_token}",
+        }
 
     def lock_project(self, project, env):
         data = {
@@ -50,30 +55,51 @@ class CaptainHook:
 
     def send_post_request(self, endpoint, data):
         try:
-            return requests.post(
-                f"{self._baseurl}{endpoint}", data=data, timeout=self._timeout
+            r = requests.post(
+                f"{self._baseurl}{endpoint}",
+                headers=self._headers,
+                data=data,
+                timeout=self._timeout,
             )
+
+            return self._response(r)
         except Exception:
             logger.error("Unable to contact Captainhook, are you using the VPN?")
             sys.exit(-1)
 
     def send_put_request(self, endpoint, data):
         try:
-            return requests.put(
-                f"{self._baseurl}{endpoint}", data=data, timeout=self._timeout
+            r = requests.put(
+                f"{self._baseurl}{endpoint}",
+                headers=self._headers,
+                data=data,
+                timeout=self._timeout,
             )
+
+            return self._response(r)
         except Exception:
             logger.error("Unable to contact Captainhook, are you using the VPN?")
             sys.exit(-1)
 
     def send_get_request(self, endpoint):
         try:
-            return requests.get(
-                f"{self._baseurl}{endpoint}", timeout=(2, self._timeout)
+            r = requests.get(
+                f"{self._baseurl}{endpoint}",
+                headers=self._headers,
+                timeout=(2, self._timeout),
             )
+
+            return self._response(r)
         except Exception:
             logger.error("Unable to contact Captainhook, are you using the VPN?")
             sys.exit(-1)
 
+    def _response(self, response):
+        if response.status_code == 401:
+            logger.error("Unauthorized. Are you logged in?")
+            sys.exit(-1)
+
+        return response
+
     def set_timeout(self, timeout):
         self._timeout = timeout
